/*--------------------------------------------------------------------------*/
/* Communication Library for FlashRunner 2.0 Programmer						*/
/* Version: 02.00.01.00 - 21/03/2023										*/
/*                                                                          */
/* Copyright (c) 2023 SMH Technologies	                                    */
/*--------------------------------------------------------------------------*/

#ifndef FR_COMM_H
#define FR_COMM_H

/////////////////////////////////////////////////////////////////////////////
// Programmer
/////////////////////////////////////////////////////////////////////////////
#ifndef FR_COMM_API
	#ifdef FR_COMM_EXPORTS
		#define FR_COMM_API __declspec(dllexport) 
	#else
		#define FR_COMM_API __declspec(dllimport) 
	#endif
#endif

typedef void *FR_COMM_HANDLE;
typedef unsigned long FR_COMM_ERR;

typedef FR_COMM_ERR (WINAPI *FR_FileTransferProgressProc)(unsigned long file_size, unsigned long file_pos);

/////////////////////////////////////////////////////////////////////////////
#ifdef __cplusplus
extern "C" {
#endif

// ** Error message strings
FR_COMM_API 
void WINAPI FR_GetLastErrorMessageW(wchar_t *error_msg, unsigned long string_len);
FR_COMM_API 
void WINAPI FR_GetLastErrorMessageA(char *error_msg, unsigned long string_len);

// ** Open the communication ports 
FR_COMM_API 
FR_COMM_HANDLE WINAPI FR_OpenCommunicationW(const wchar_t *com_port, const wchar_t *com_settings);
FR_COMM_API 
FR_COMM_HANDLE WINAPI FR_OpenCommunicationA(const char *com_port, const char *com_settings);
// ** Close communication
FR_COMM_API 
FR_COMM_ERR WINAPI FR_CloseCommunicationW(FR_COMM_HANDLE handle);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_CloseCommunicationA(FR_COMM_HANDLE handle);

//** Commands transmission
FR_COMM_API 
FR_COMM_ERR WINAPI FR_SendCommandW(FR_COMM_HANDLE handle, const wchar_t *command);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_SendCommandA(FR_COMM_HANDLE handle, const char *command);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_GetAnswerW(FR_COMM_HANDLE handle, wchar_t *answer, unsigned long maxlen, unsigned long timeout_ms);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_GetAnswerA(FR_COMM_HANDLE handle, char *answer, unsigned long maxlen, unsigned long timeout_ms);

//** File Transfer
FR_COMM_API 
FR_COMM_ERR WINAPI FR_SendFileW(FR_COMM_HANDLE handle, const wchar_t *protocol, const wchar_t *src_filename, const wchar_t *dst_path, FR_FileTransferProgressProc progress);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_SendFileA(FR_COMM_HANDLE handle, const char *protocol, const char *src_filename, const char *dst_path, FR_FileTransferProgressProc progress);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_GetFileW(FR_COMM_HANDLE handle, const wchar_t *protocol, const wchar_t *src_filename, const wchar_t *dst_path, const wchar_t *filetype, FR_FileTransferProgressProc progress);
FR_COMM_API 
FR_COMM_ERR WINAPI FR_GetFileA(FR_COMM_HANDLE handle, const char *protocol, const char *src_filename, const char *dst_path, const char *filetype, FR_FileTransferProgressProc progress);

// ** Dll Version
FR_COMM_API
void WINAPI GetDllVersion(unsigned int *major, unsigned int *minor, unsigned int *build, unsigned int *revision);

// ** Cybersecurity
FR_COMM_API
FR_COMM_ERR WINAPI FR_GetPublicKey(FR_COMM_HANDLE handle);
FR_COMM_API
FR_COMM_ERR WINAPI FR_EncryptData(FR_COMM_HANDLE handle, const unsigned char* data_to_encrypt, unsigned int len_data, unsigned char* header, unsigned char* data_encrypted);
FR_COMM_API
FR_COMM_ERR WINAPI FR_HexToAsciiStream(const unsigned char* data_hex, unsigned int len_data, char* data_ascii);

#ifdef UNICODE
	#define FR_GetLastErrorMessage	FR_GetLastErrorMessageW
	#define FR_OpenCommunication	FR_OpenCommunicationW
	#define FR_CloseCommunication	FR_CloseCommunicationW
	#define FR_SendCommand			FR_SendCommandW
	#define FR_GetAnswer			FR_GetAnswerW
	#define FR_SendFile				FR_SendFileW
	#define FR_GetFile				FR_GetFileW
#else
	#define FR_GetLastErrorMessage	FR_GetLastErrorMessageA
	#define FR_OpenCommunication	FR_OpenCommunicationA
	#define FR_CloseCommunication	FR_CloseCommunicationA
	#define FR_SendCommand			FR_SendCommandA
	#define FR_GetAnswer			FR_GetAnswerA
	#define FR_SendFile				FR_SendFileA
	#define FR_GetFile				FR_GetFileA
#endif

#ifdef __cplusplus
}
#endif

#endif  /* FR_COMM_H */





